@@ -226,14 +226,14 @@ final class AwsProtocolUtils {
     public static void writeJsonErrorMessageCodeDeserializer(GenerationContext context) {
         GoWriter writer = context.getWriter().get();
         // The error code could be in the headers, even though for this protocol it should be in the body.
-        writer.write("code := response.Header.Get(\"X-Amzn-ErrorType\")");
-        writer.write("if len(code) != 0 { errorCode = restjson.SanitizeErrorCode(code) }");
+        writer.write("headerCode := response.Header.Get(\"X-Amzn-ErrorType\")");
+        writer.write("if len(headerCode) != 0 { errorCode = restjson.SanitizeErrorCode(headerCode) }");
         writer.write("");
 
         initializeJsonDecoder(writer, "errorBody");
         writer.addUseImports(AwsGoDependency.AWS_REST_JSON_PROTOCOL);
         // This will check various body locations for the error code and error message
-        writer.write("code, message, err := restjson.GetErrorInfo(decoder)");
+        writer.write("jsonCode, message, err := restjson.GetErrorInfo(decoder)");
         handleDecodeError(writer);
 
         writer.addUseImports(SmithyGoDependency.IO);
@@ -241,7 +241,8 @@ final class AwsProtocolUtils {
         writer.write("errorBody.Seek(0, io.SeekStart)");
 
         // Only set the values if something was found so that we keep the default values.
-        writer.write("if len(code) != 0 { errorCode = restjson.SanitizeErrorCode(code) }");
+        // The header version of the error wins out over either of the body fields.
+        writer.write("if len(headerCode) == 0 && len(jsonCode) != 0 { errorCode = restjson.SanitizeErrorCode(jsonCode) }");
         writer.write("if len(message) != 0 { errorMessage = message }");
         writer.write("");
     }
