@@ -33,7 +33,7 @@ import software.amazon.smithy.go.codegen.GoStackStepMiddlewareGenerator;
 import software.amazon.smithy.go.codegen.GoValueAccessUtils;
 import software.amazon.smithy.go.codegen.GoWriter;
 import software.amazon.smithy.go.codegen.SmithyGoDependency;
-import software.amazon.smithy.go.codegen.SyntheticClone;
+import software.amazon.smithy.go.codegen.Synthetic;
 import software.amazon.smithy.go.codegen.integration.HttpBindingProtocolGenerator;
 import software.amazon.smithy.go.codegen.integration.ProtocolGenerator;
 import software.amazon.smithy.go.codegen.integration.ProtocolUtils;
@@ -64,7 +64,7 @@ import software.amazon.smithy.model.traits.XmlNamespaceTrait;
  * It handles reading and writing from document bodies, including generating any
  * functions needed for performing serde.
  *
- * @see <a href="https://awslabs.github.io/smithy/spec/http.html">Smithy HTTP protocol bindings.</a>
+ * @see <a href="https://smithy.io/2.0/spec/http-bindings.html">Smithy HTTP protocol bindings.</a>
  */
 abstract class RestJsonProtocolGenerator extends HttpBindingProtocolGenerator {
     private final Set<ShapeId> generatedDocumentBodyShapeSerializers = new HashSet<>();
@@ -119,7 +119,7 @@ abstract class RestJsonProtocolGenerator extends HttpBindingProtocolGenerator {
         Shape payloadShape = model.expectShape(memberShape.getTarget());
 
         String functionName;
-        if (payloadShape.hasTrait(SyntheticClone.class)) {
+        if (payloadShape.hasTrait(Synthetic.class)) {
             functionName = ProtocolGenerator.getDocumentSerializerFunctionName(
                     payloadShape, context.getService(), context.getProtocolName());
         } else {
@@ -293,7 +293,6 @@ abstract class RestJsonProtocolGenerator extends HttpBindingProtocolGenerator {
         });
     }
 
-
     // Write middleware that delegates to deserializers for shapes that have implicit payload and deserializer
     private void writeMiddlewareDocumentBindingDeserializerDelegator(
             GenerationContext context,
